library(ape)
library(dplyr)

##formspace results----
x <- read.table("form1results_formatted.txt", header=T)
##rescaled.nex
tree <- read.nexus("rescaled_formspace.nex")

# First get the nodes as before using the tree (it would be better to plot on the
#original, rather than rescaled tree)
node <- c(1:length(tree$tip.label), (length(tree$tip.label)+1):dim(tree$edge)[1]+1)

# The do the indexing
idx <- tree$edge[,2]
idx[which(idx>length(tree$tip.label))] <- idx[which(idx>length(tree$tip.label))]-1

# Now we can make our rates data frame. Note that we need to use x[-1,] to remove the 
#first row of the data because this refers to the root edge of the tree but that doesn't 
#correspond to anything in the input phylo object. I have also removed the last column 
#(the vectors of species name). Again, this data frame can be used to get the tip rates
#(the rows with species names).
brates <- data.frame(node=node[idx], x[-1,-22])

rownames(brates) <- c(tree$tip.label, (length(tree$tip.label)):(length(x[-1,1]))+1)[idx]
write.csv(brates, "brates_form.csv")
brates<-read.csv("bratesform.csv")
rownames(brates)<-brates$X
brates<-select(brates,!X)


#actually relevant trait rates
tipbrates<-brates %>% filter(No_Taxa==1)
tipbrates<-tipbrates %>% select(Median_SigV)
write.csv(tipbrates, "brates_form_tiprates.csv")

rm(list=ls())
##morphospace results----
x <- read.table("morphresults_formatted.txt", header=T)
##rescaled.nex
tree <- read.nexus("rescaled_morphospace.nex")

# First get the nodes as before using the tree (it would be better to plot on the
#original, rather than rescaled tree)
node <- c(1:length(tree$tip.label), (length(tree$tip.label)+1):dim(tree$edge)[1]+1)

# The do the indexing
idx <- tree$edge[,2]
idx[which(idx>length(tree$tip.label))] <- idx[which(idx>length(tree$tip.label))]-1

# Now we can make our rates data frame. Note that we need to use x[-1,] to remove the 
#first row of the data because this refers to the root edge of the tree but that doesn't 
#correspond to anything in the input phylo object. I have also removed the last column 
#(the vectors of species name). Again, this data frame can be used to get the tip rates
#(the rows with species names).
brates <- data.frame(node=node[idx], x[-1,-22])

rownames(brates) <- c(tree$tip.label, (length(tree$tip.label)):(length(x[-1,1]))+1)[idx]
write.csv(brates, "brates_morph.csv")
brates<-read.csv("brates_morph.csv")
rownames(brates)<-brates$X
brates<-select(brates,!X)


#actually relevant trait rates
tipbrates<-brates %>% filter(No_Taxa==1)
tipbrates<-tipbrates %>% select(Median_SigV)
write.csv(tipbrates, "brates_morph_tiprates.csv")

rm(list=ls())
##body size results----
x <- read.table("logbodyresults_formatted.txt", header=T)
##rescaled.nex
tree <- read.nexus("rescaled_bodysize.nex")

# First get the nodes as before using the tree (it would be better to plot on the
#original, rather than rescaled tree)
node <- c(1:length(tree$tip.label), (length(tree$tip.label)+1):dim(tree$edge)[1]+1)

# The do the indexing
idx <- tree$edge[,2]
idx[which(idx>length(tree$tip.label))] <- idx[which(idx>length(tree$tip.label))]-1

# Now we can make our rates data frame. Note that we need to use x[-1,] to remove the 
#first row of the data because this refers to the root edge of the tree but that doesn't 
#correspond to anything in the input phylo object. I have also removed the last column 
#(the vectors of species name). Again, this data frame can be used to get the tip rates
#(the rows with species names).
brates <- data.frame(node=node[idx], x[-1,-22])

rownames(brates) <- c(tree$tip.label, (length(tree$tip.label)):(length(x[-1,1]))+1)[idx]
write.csv(brates, "brates_body.csv")
brates<-read.csv("brates_body.csv")
rownames(brates)<-brates$X
brates<-select(brates,!X)


#actually relevant trait rates
tipbrates<-brates %>% filter(No_Taxa==1)
tipbrates<-tipbrates %>% select(Median_SigV)
write.csv(tipbrates, "brates_body_tiprates.csv")


rm(list=ls())
##rel bill size results----
x <- read.table("billoverbodyresults2_formatted.txt", header=T)
##rescaled.nex
tree <- read.nexus("rescaled_relbill.nex")

# First get the nodes as before using the tree (it would be better to plot on the
#original, rather than rescaled tree)
node <- c(1:length(tree$tip.label), (length(tree$tip.label)+1):dim(tree$edge)[1]+1)

# The do the indexing
idx <- tree$edge[,2]
idx[which(idx>length(tree$tip.label))] <- idx[which(idx>length(tree$tip.label))]-1

# Now we can make our rates data frame. Note that we need to use x[-1,] to remove the 
#first row of the data because this refers to the root edge of the tree but that doesn't 
#correspond to anything in the input phylo object. I have also removed the last column 
#(the vectors of species name). Again, this data frame can be used to get the tip rates
#(the rows with species names).
brates <- data.frame(node=node[idx], x[-1,-22])

rownames(brates) <- c(tree$tip.label, (length(tree$tip.label)):(length(x[-1,1]))+1)[idx]
write.csv(brates, "brates_relbill.csv")
brates<-read.csv("brates_relbill.csv")
rownames(brates)<-brates$X
brates<-select(brates,!X)


#actually relevant trait rates
tipbrates<-brates %>% filter(No_Taxa==1)
tipbrates<-tipbrates %>% select(Median_SigV)
write.csv(tipbrates, "brates_relbill_tiprates.csv")
